import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import EventEmitter from 'event-emitter';

export var WindowStub = function WindowStub(initialPath) {
  _classCallCheck(this, WindowStub);

  this.document = {
    location: {
      href: 'http://address/' + initialPath,
      pathname: initialPath,
      search: ''
    },

    referrer: 'http://referrer1',

    querySelector: function querySelector() {
      return true;
    }
  };
};

export var HistoryStub = function () {
  function HistoryStub() {
    var _this = this;

    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [{ data: {}, title: null, hash: 'url' }];

    _classCallCheck(this, HistoryStub);

    this.Adapter = {
      bind: function bind(scope, event, callback) {
        _this.historyEmitter.on('updateState', function () {
          return callback();
        });
      }
    };

    this.historyEmitter = new EventEmitter();
    this.position = state.length === 0 ? 0 : state.length - 1;
    this.state = [].concat(state);
  }

  HistoryStub.prototype.getState = function getState() {
    return this.state[this.position];
  };

  HistoryStub.prototype.replaceState = function replaceState(data, title, href) {
    var _state$position = this.state[this.position],
        currentData = _state$position.data,
        currentTitle = _state$position.title,
        currentUrl = _state$position.hash;


    var newState = {
      data: data || currentData,
      title: title || currentTitle,
      hash: href || currentUrl
    };

    this.state = [].concat(this.state.slice(0, this.position), [newState]);

    this.historyEmitter.emit('updateState');
  };

  HistoryStub.prototype.pushState = function pushState(data, title, href) {
    var _state$position2 = this.state[this.position],
        currentData = _state$position2.data,
        currentTitle = _state$position2.title,
        currentUrl = _state$position2.hash;


    var newState = {
      data: data || currentData,
      title: title || currentTitle,
      hash: href || currentUrl
    };

    this.state = [].concat(this.state.slice(0, this.position + 1), [newState]);

    this.position = this.position + 1;
    this.historyEmitter.emit('updateState');
  };

  HistoryStub.prototype.back = function back() {
    this.position = this.position - 1;
    this.historyEmitter.emit('updateState');
  };

  HistoryStub.prototype.forward = function forward() {
    if (this.state[this.position + 1]) {
      this.position = this.position + 1;
      this.historyEmitter.emit('updateState');
    }
  };

  return HistoryStub;
}();